// ***************************************************************************
// LogAdapter Class
// 
//
// Class Description:  
// ------------------
// Purpose:  This class is a utility class for filling Components with information
// from sequential files.  Moreover the scl_types.dat file.  The access to these 
// files is only read, not write. 
//
// System Relationship:  Intercommunication with the whole system is minimal.  The
// majority of system relationships involves filling List or Choice components 
// located on other interfaces.  For example, filling an Scl Types list in the Scl
// Interface.
//
// Requirements:  This class requires the Java Developemnt Kit (JDK) 1.0.
// Aside from this there are no special algorithms, or constraints.  
//
// Pre-Conditions:  None.
//
// Post Conditions: None.
//
// Error Handling:  Addressed with the try and catch clause.
//
//
// Class Specification:
// --------------------
// This clas must open a file read from it and close the file.  Moreover, informaiton
// retrieved from a file is then added to a Component (List or Choice).  The majority
// of functionality of this class is completing the preceeding tasks.
//
//
// Methods
// -------
//      public List fillList (List list)
//      public List fillList (List list, String srcFile, String delimeter)
//      public Choice fillChoice (Choice choice)
//      public String[] getSclTypes()
//
//
// *****************************************************************************

import java.io.*;
import java.lang.*;
import java.util.*;
import java.awt.*;

public class LogAdapter {


  // *********************************************************************************
  // public List fillList (List list)
  //
  // Method Description:  This method retrieves each record from the scl_types.dat file
  // and fills a List with the Scl types name.
  //
  // Method Specification:  This method requires a source file, and a List to fill.
  // It will then proceed to fill the list with the names of the Scl types found in the
  // scl_types.dat file.  It will then return this list.
  //   
  // This method will be accessed several times.  Every time a tab/feature that has a
  // Scl list is activated, this method will be accessed.
  //
  // Pre-Condition:  The source file should exist. The List needs to be instantiated.
  //
  // Post-Condition: The text is added to the List and returned to the calling parent.
  // 
  // *********************************************************************************

  public List fillList (List list) {
    String token = "";
   
    File stuff = new File(Atom.sclTypesFile);

   // Check for file existence
   // If it does not exist inform the user
   if (!(stuff.exists())) {
     System.out.println(Atom.sclTypesFile);
     System.out.println("File Does Not Exist");
     return list;
   }
   try {
     DataInputStream sourceFile = new DataInputStream
       (new FileInputStream(Atom.sclTypesFile));

     // 
     // While the file is not EOF
     //    * Get a line of the source file
     //    * Parse the input line using the carot as a token delimiter
     //
     do {
       String str = sourceFile.readLine();   
       if (str == null) break;
       StringTokenizer inputString = new StringTokenizer(str, "^");        
       token = inputString.nextToken();
       list.addItem(token);    	   
     } while (true);

   }  // try 

   catch(Exception e) {
     String err = e.toString();
     System.out.println(err);
     System.out.println("Testing: just hit exception in LogAdapter.fillList(List)");
   } // catch

  return list;

 }   // fillList


  // *********************************************************************************
  // public List fillList (List list, String srcFile, String delimeter)
  //
  // Method Description:  This method retrieves each record from the scl_types.dat file
  // and fills a List with the Scl types name.
  //
  // Method Specification:  This method requires a source file, and a List to fill.
  // It will then proceed to fill the list with the names of the Scl types found in the
  // scl_types.dat file.  It will then return this list.
  //   
  // This method will be accessed several times.  Every time a tab/feature that has a
  // Scl list is activated, this method will be accessed.
  //
  // Pre-Condition:  The source file should exist. The List needs to be instantiated.
  //
  // Post-Condition: The text is added to the List and returned to the calling parent.
  // 
  // *********************************************************************************

  public List fillList (List list, String srcFile, String delimeter) {
    String token = "";

    // Check for file existence
    // If it does not exist inform the user
    File fileCheck = new File(srcFile);
    if(!(fileCheck.exists())) {
      return list;
    }

   try {
     DataInputStream sourceFile = new DataInputStream
       (new FileInputStream(srcFile));

     // 
     // While the file is not EOF
     //    * Get a line of the source file
     //    * Parse the input line using whitespace as a token delimiter
     //
     do {
       String completeToken = "";
       String str = sourceFile.readLine();
       if (str == null) break;
        StringTokenizer inputString = new StringTokenizer(str, " ");
        
          token = inputString.nextToken();
	 
	  // Make sure to get the full token or full name
	  if (token.equals(delimeter)) {                 
	    while (inputString.hasMoreTokens()) {
	      token = inputString.nextToken();	      
	      completeToken = completeToken+" "+token;	 
	    }
	    completeToken = completeToken.trim();
	    list.addItem(completeToken);    	    
	  }
     } while (true);
   }  // try 

   catch(Exception e) {
     String err = e.toString();
     System.out.println(err);
     System.out.println("Testing: just hit exception in LogAdapter.fillList(List,String,String)");
   } // catch

   return list;

  }   // fillList


  // *********************************************************************************
  // public Choice fillChoice (Choice choice)
  //
  // Method Description:  This method retrieves each record from the scl_types.dat file
  // and fills a Choice menu with the Scl types name.
  //
  // Method Specification:  This method requires a source file, and a Choice menu to fill.
  // It will then proceed to fill the menu with the names of the Scl types found in the
  // scl_types.dat file.  It will then return this Choice menu.
  //   
  // This method will be accessed several times.  Every time a tab/feature that has a
  // Scl Choice menu is activated, this method will be accessed.
  //
  // Pre-Condition:  The source file should exist. The Choice menu needs to be instantiated.
  //
  // Post-Condition: The text is added to the Choice menu and returned to the calling parent.
  // 
  // *********************************************************************************

  public Choice fillChoice (Choice choice) {
   String token = "";

   try {
     DataInputStream sourceFile = new DataInputStream
       (new FileInputStream(Atom.sclTypesFile));

     // 
     // While the file is not EOF
     //    * Get a line of the source file
     //    * Parse the input line using whitespace as a token delimiter
     //  
     do {
       String str = sourceFile.readLine();
       if (str == null) break;
        StringTokenizer inputString = new StringTokenizer(str, "^");
        
          token = inputString.nextToken();
          choice.addItem(token);    
	  
     } while (true);
   }  // try 

   catch(Exception e) {
     String err = e.toString();
     System.out.println(err);
     System.out.println("Testing: just hit exception in LogAdapter.fillList(List)");
   } // catch

   return choice;

 }   // fillChoice


  // *********************************************************************************
  // public String[] getSclTypes ()
  //
  // Method Description:  This method retrieves each record from the scl_types.dat file
  // and stores it into a string array to return to the calling parent class.  
  // Not used in current release.
  //
  // Method Specification:  This method uses the scl_types.dat source file to retrieve its
  // information.  It will then take each record in this file and store the names of the 
  // scl types into an array that it returns to the calling parent method.
  //   
  // Pre-Condition:  The source file should exist. 
  //
  // Post-Condition: Returns the String array.
  // 
  // *********************************************************************************

  public String[] getSclTypes () {
    String token = "";
    String[] sclTypes = new String[30];
    int index = 0;
    
    try {
      DataInputStream sourceFile = new DataInputStream
        (new FileInputStream(Atom.sclTypesFile));

     // 
     // While the file is not EOF
     //    * Get a line of the source file
     //    * Parse the input line using whitespace as a token delimiter
     //  
      do {
	String str = sourceFile.readLine();
	if (str == null) break;
        StringTokenizer inputString = new StringTokenizer(str, "^");
        
	token = inputString.nextToken();
        sclTypes[index] = token;
	index++;        

      } while (true);
    }  // try 

    catch(Exception e) {
      String err = e.toString();
      System.out.println(err);
      System.out.println("Testing: just hit exception in LogAdapter.getSclTypes()");
    } // catch

    // return string of exact size. save on mem hopefully
    String[] returnString = new String[index];

    for (int k=0; k<index; k++) {
      returnString[k] = sclTypes[k];
    }

    return returnString;

  }  // getSclTypes          

} // LogAdapter
